import React from 'react';
import { useState, lazy, Suspense } from 'react';
import { FileAudio, Languages, Mic } from 'lucide-react';
import { AudioRecorder } from './components/AudioRecorder';
import { FileUpload } from './components/FileUpload';
import { Features as HomeFeatures } from './components/Features';
import { Footer } from './components/Footer';
import { TranscriptionOutput } from './components/TranscriptionOutput';
import { SkyBackground } from './components/SkyBackground';
import { transcribeAudio, generateSpeech } from './lib/openai';
import type { TranscriptionResult, ExportFormat } from './types'
import { trackEvent } from './lib/analytics';

function App() {
  const [isProcessing, setIsProcessing] = useState(false);
  const [processingStatus, setProcessingStatus] = useState<string>('');
  const [result, setResult] = useState<TranscriptionResult | null>(null);
  const [activeTab, setActiveTab] = useState<'upload' | 'record'>('upload');
  const [selectedLanguage, setSelectedLanguage] = useState<string>('en');

  const handleFileSelect = async (file: File) => {
    try {
      setIsProcessing(true);
      setProcessingStatus('Uploading audio file...');
      
      await new Promise(resolve => setTimeout(resolve, 1000));
      setProcessingStatus('Transcribing audio...');
      
      const transcription = await transcribeAudio(file, {
        language: selectedLanguage,
      });

      setProcessingStatus('Finalizing results...');
      await new Promise(resolve => setTimeout(resolve, 500));
      
      setResult(transcription);
      
      // Track successful transcription
      trackEvent('transcription', 'complete', selectedLanguage, file.size);
    } catch (error) {
      console.error('Transcription error:', error);
      // Track transcription error
      trackEvent('transcription', 'error', error instanceof Error ? error.message : 'Unknown error');
    } finally {
      setIsProcessing(false);
      setProcessingStatus('');
    }
  };

  const handleRecordingComplete = async (blob: Blob) => {
    const file = new File([blob], 'recording.webm', { type: 'audio/webm' });
    trackEvent('recording', 'complete', 'webm', blob.size);
    await handleFileSelect(file);
  };

  const handleExport = (format: ExportFormat) => {
    if (!result) return;

    let content = '';
    let mimeType = '';
    let filename = '';

    switch (format) {
      case 'txt':
        content = result.text;
        mimeType = 'text/plain';
        filename = 'transcription.txt';
        break;
      case 'srt':
        content = result.segments?.map((segment, i) => {
          const start = new Date(segment.start * 1000).toISOString().substr(11, 12).replace('.', ',');
          const end = new Date(segment.end * 1000).toISOString().substr(11, 12).replace('.', ',');
          return `${i + 1}\n${start} --> ${end}\n${segment.text}\n`;
        }).join('\n') || '';
        mimeType = 'text/plain';
        filename = 'transcription.srt';
        break;
      default:
        return;
    }

    const blob = new Blob([content], { type: mimeType });
    const url = URL.createObjectURL(blob);
    const a = document.createElement('a');
    a.href = url;
    a.download = filename;
    a.click();
    URL.revokeObjectURL(url);
  };

  const handleTextToSpeech = async (text: string) => {
    try {
      const audioUrl = await generateSpeech(text);
      const audio = new Audio(audioUrl);
      audio.play();
    } catch (error) {
      console.error('Text-to-speech error:', error);
    }
  };

  return (
    <div className="min-h-screen relative">
      <SkyBackground />
      <div className="relative max-w-4xl mx-auto py-6 sm:py-12 px-3 sm:px-4 animate-fade-in">
        <div className="text-center mb-8">
          <h1 className="text-4xl sm:text-6xl font-extrabold gradient-text mb-3 sm:mb-4 tracking-tight [text-shadow:_0_1px_2px_rgb(0_0_0_/_5%)]">
            AudioToText.xyz
          </h1>
          <p className="text-lg sm:text-xl text-primary-700 font-medium">
            Professional AI-Powered Audio Transcription
          </p>
          <div className="flex justify-center mt-4">
            <a 
              href="https://www.producthunt.com/posts/audiototext-xyz?embed=true&utm_source=badge&utm_medium=badge&utm_souce=badge-audiototext&#0045;xyz" 
              target="_blank" 
              rel="noopener noreferrer"
            >
              <img 
                src="https://api.producthunt.com/widgets/embed-image/v1/featured.svg?post_id=880800&theme=light&t=1739555083234" 
                alt="AudioToText&#0046;xyz - Professional&#0032;AI&#0045;Powered&#0032;Audio&#0032;Transcription | Product Hunt" 
                className="h-[54px] w-[250px]"
                width="250" 
                height="54" 
              />
            </a>
          </div>
        </div>

        <div className="glass neumorphic rounded-xl sm:rounded-2xl p-4 sm:p-8 mb-6 sm:mb-8 transition-all duration-300 hover:shadow-lg">
          <div className="flex flex-col sm:flex-row gap-2 sm:gap-4 mb-4 sm:mb-6">
            <button
              onClick={() => setActiveTab('upload')}
              className={`flex items-center justify-center gap-2 px-4 py-3 rounded-lg transition-colors ${
                activeTab === 'upload'
                  ? 'bg-secondary-100 text-secondary font-medium scale-105'
                  : 'text-primary-700 hover:bg-primary-50 hover:scale-105'
              }`}
            >
              <FileAudio className="w-5 h-5" />
              Upload File
            </button>
            <button
              onClick={() => setActiveTab('record')}
              className={`flex items-center justify-center gap-2 px-4 py-3 rounded-lg transition-colors ${
                activeTab === 'record'
                  ? 'bg-secondary-100 text-secondary font-medium scale-105'
                  : 'text-primary-700 hover:bg-primary-50 hover:scale-105'
              }`}
            >
              <Mic className="w-5 h-5" />
              Record Audio
            </button>
          </div>

          <div className="mb-6">
            <div className="flex items-center gap-2 mb-4">
              <Languages className="w-5 h-5 text-primary-700" />
              <select
                value={selectedLanguage}
                onChange={(e) => setSelectedLanguage(e.target.value)}
                className="block w-40 rounded-lg border-2 border-primary-100 bg-white/50 focus:border-secondary focus:ring-2 focus:ring-secondary-100 transition-all"
              >
                <option value="en">English</option>
                <option value="hi">Hindi</option>
                <option value="ja">Japanese</option>
                <option value="es">Spanish</option>
                <option value="fr">French</option>
              </select>
            </div>

            {activeTab === 'upload' ? (
              <FileUpload
                onFileSelect={handleFileSelect}
                isProcessing={isProcessing}
                processingStatus={processingStatus}
              />
            ) : (
              <AudioRecorder
                onRecordingComplete={handleRecordingComplete}
                isProcessing={isProcessing}
                processingStatus={processingStatus}
              />
            )}
            {isProcessing && (
              <div className="mt-4">
                <div className="h-2 w-full bg-gray-200 rounded-full overflow-hidden">
                  <div 
                    className="h-full bg-gradient-to-r from-secondary to-accent rounded-full transition-all duration-500"
                    style={{ 
                      width: processingStatus.includes('Uploading') ? '33%' : 
                             processingStatus.includes('Transcribing') ? '66%' : 
                             processingStatus.includes('Finalizing') ? '90%' : '0%' 
                    }}
                  />
                </div>
                <p className="text-sm text-primary-700 mt-2 text-center font-medium">{processingStatus}</p>
              </div>
            )}
          </div>
        </div>

        {result && (
          <div className="animate-fade-in">
            <TranscriptionOutput
              result={result}
              onExport={handleExport}
              onTextToSpeech={handleTextToSpeech}
            />
          </div>
        )}
        
        <HomeFeatures />
      </div>
      <Footer />
    </div>
  );
}

export default App;